aboutsummaryrefslogtreecommitdiffstats
path: root/include/zot.php
diff options
context:
space:
mode:
Diffstat (limited to 'include/zot.php')
-rw-r--r--include/zot.php16
1 files changed, 8 insertions, 8 deletions
diff --git a/include/zot.php b/include/zot.php
index 20ec7686d..8f76e78b1 100644
--- a/include/zot.php
+++ b/include/zot.php
@@ -2,14 +2,14 @@
/**
*
* @function zot_new_uid($entity_nick)
* @entity_id = unique nickname of controlling entity
* @returns string
*
*/
-function zot_new_uid($entity_nick) {
- $rawstr = z_root() . '/' . $entity_nick . '.' . mt_rand();
+function zot_new_uid($channel_nick) {
+ $rawstr = z_root() . '/' . $channel_nick . '.' . mt_rand();
return(base64url_encode(hash('whirlpool',$rawstr,true),true));
}
@@ -59,13 +59,13 @@ function zot_verify(&$item,$identity) {
-function zot_notify($entity,$url) {
+function zot_notify($channel,$url) {
$x = z_post_url($url, array(
'type' => 'notify',
- 'guid' => $entity['entity_global_id'],
- 'guid_sig' => base64url_encode($guid,$entity['prvkey']),
+ 'guid' => $channel['channel_global_id'],
+ 'guid_sig' => base64url_encode($guid,$channel['prvkey']),
'hub' => z_root(),
- 'hub_sig' => base64url_encode(z_root,$entity['prvkey']),
+ 'hub_sig' => base64url_encode(z_root,$channel['prvkey']),
'callback' => '/post',
'spec' => ZOT_REVISION)
);
@@ -2,14 +2,14 @@
/**
*
- * @function zot_new_uid($entity_nick)
- * @entity_id = unique nickname of controlling entity
+ * @function zot_new_uid($channel_nick)
+ * @channel_id = unique nickname of controlling entity
* @returns string
*